<?php
App::uses('EvSitemapAppController', 'EvSitemap.Controller');

class SitemapsController extends EvSitemapAppController {

	/**
	 * Components
	 */
	public $components = array(
		'RequestHandler'
	);

	/**
	 * Helpers
	 */
	public $helpers = array(
		'Html',
		'Time'
	);

	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow(array(
			'index'
		));
	}

	public function index() {
		$listing = array();

		$pageId = Configure::read('EvSitemap.page_id');

		if (! empty($pageId)) {
			$this->loadModel('Page');
			$this->set('data', $this->Page->readForView($pageId));
		}

		// assign list of models to be used within the sitemap
		$modelListing = $this->_getModelListing();

		if (! empty($modelListing)) {
			foreach ($modelListing as $modelName) {

				list($plugin, $model) = pluginSplit($modelName);

				try {
					$Model = $this->loadModel(ucwords($modelName));

				} catch(\Exception $e) {
					continue;
				}

				$Model = ClassRegistry::init(ucwords($modelName));

				if (isset($Model->actsAs) && array_key_exists('EvSitemap.Sitemap', $Model->actsAs)) {
					$key = ! empty($Model->actsAs['EvSitemap.Sitemap']['listingTitle']) ? $Model->actsAs['EvSitemap.Sitemap']['listingTitle'] : $Model->name;
					$listing[$key] = $Model->getSitemapData();
				}

				unset($Model);
			}
		}

		$this->set(compact('listing'));

		return;
	}

	protected function _getModelListing() {
		$listing = array();

		$ignoreList = Configure::read('EvSitemap.modelIgnoreList');

		// Get all the models in the main app model directory
		$modelList = App::objects('Model');

		// get all the plugins so we can get all their models
		$pluginList = App::objects('plugins');

		// loop and get the models
		foreach ($pluginList as $plugin) {

			// get the plugin models and prefix with the plugin name
			$pluginModel = App::objects($plugin . '.Model');

			foreach ($pluginModel as $key => $model) {

				$pluginModel[$key] = $plugin . '.' . $model;
			}

			$modelList = array_merge($modelList, $pluginModel);
		}

		if (! empty($modelList)) {

			foreach ($modelList as $modelName) {

				if (in_array($modelName, $ignoreList)) {

					continue;
				}

				$listing[] = $modelName;
			}
		}

		return $listing;
	}

}
